## MP3 player

### Description

Conjoint data from one respondent. Ratings reflect the evaluation of 18 alternative MP3 players. The 18 profiles are an orthogonal fractional factorial design.

### Format

A data frame with 18 observations on 6 variables.

- Rating =	 Respondent rating on a scale from 1-100. Higher ratings imply a preferred profile.
- Memory	= GB of memory in the MP3 player
- Radio = Does the MP3 player have a radio yes or no
- Size = Size of the MP3 player (demo provided)
- Price = Price of the MP3 player
- Shape = Shape of the MP3 player